pub fn deregister<T: Config>(para_id: ParaId)Expand description
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::deregister.
pub fn deregister<T: Config>(para_id: ParaId)This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::deregister.