referrerpolicy=no-referrer-when-downgrade

reserve

Function reserve 

pub fn reserve<T: Config>()
Reserve the next free para id for the caller.

Takes Config::ReservationConsideration. The caller becomes the manager of the new id and is the only account that may Pallet::register against it.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::reserve.