pub fn add_lock<T: Config>(para_id: ParaId)Expand description
Lock a registered para, keeping the manager out of it.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::add_lock.